@@ -247,7 +247,7 @@ class IBMQBackend(Backend):
         super().__init__()
         self._pytket_config = QiskitConfig.from_default_config_file()
         self._provider = (
-            self._get_provider(hub, group, project)
+            self._get_provider(hub, group, project, self._pytket_config)
             if account_provider is None
             else account_provider
         )
@@ -255,41 +255,8 @@ class IBMQBackend(Backend):
         self._config = self._backend.configuration()
         self._max_per_job = getattr(self._config, "max_experiments", 1)
 
-        # gather and store device specifics in BackendInfo
-        characterisation = process_characterisation(self._backend)
-        averaged_errors = get_avg_characterisation(characterisation)
-        characterisation_keys = [
-            "t1times",
-            "t2times",
-            "Frequencies",
-            "GateTimes",
-        ]
-        arch = characterisation["Architecture"]
-        # filter entries to keep
-        filtered_characterisation = {
-            k: v for k, v in characterisation.items() if k in characterisation_keys
-        }
-        supports_mid_measure = self._config.simulator or self._config.multi_meas_enabled
-        supports_fast_feedforward = supports_mid_measure
-        # simulator i.e. "ibmq_qasm_simulator" does not have `supported_instructions`
-        # attribute
         gate_set = _tk_gate_set(self._backend)
-        self._backend_info = BackendInfo(
-            type(self).__name__,
-            backend_name,
-            __extension_version__,
-            arch,
-            gate_set,
-            supports_midcircuit_measurement=supports_mid_measure,
-            supports_fast_feedforward=supports_fast_feedforward,
-            all_node_gate_errors=characterisation["NodeErrors"],
-            all_edge_gate_errors=characterisation["EdgeErrors"],
-            all_readout_errors=characterisation["ReadoutErrors"],
-            averaged_node_gate_errors=averaged_errors["node_errors"],
-            averaged_edge_gate_errors=averaged_errors["edge_errors"],
-            averaged_readout_errors=averaged_errors["readout_errors"],
-            misc={"characterisation": filtered_characterisation},
-        )
+        self._backend_info = self._get_backend_info(self._backend)
 
         self._standard_gateset = gate_set >= {OpType.X, OpType.SX, OpType.Rz, OpType.CX}
 
@@ -300,22 +267,39 @@ class IBMQBackend(Backend):
 
         self._MACHINE_DEBUG = False
 
+    @staticmethod
     def _get_provider(
-        self, hub: Optional[str], group: Optional[str], project: Optional[str]
+        hub: Optional[str],
+        group: Optional[str],
+        project: Optional[str],
+        qiskit_config: Optional[QiskitConfig],
     ) -> "AccountProvider":
         if not IBMQ.active_account():
             if IBMQ.stored_account():
                 IBMQ.load_account()
             else:
-                if self._pytket_config.ibmq_api_token is not None:
-                    IBMQ.save_account(self._pytket_config.ibmq_api_token)
+                if (
+                    qiskit_config is not None
+                    and qiskit_config.ibmq_api_token is not None
+                ):
+                    IBMQ.save_account(qiskit_config.ibmq_api_token)
                 else:
                     raise NoIBMQAccountError()
-        provider_kwargs = {}
-        provider_kwargs["hub"] = hub if hub else self._pytket_config.hub
-        provider_kwargs["group"] = group if group else self._pytket_config.group
-        provider_kwargs["project"] = project if project else self._pytket_config.project
-
+        provider_kwargs: Dict[str, Optional[str]] = {}
+        if hub:
+            provider_kwargs["hub"] = hub
+        else:
+            provider_kwargs["hub"] = qiskit_config.hub if qiskit_config else None
+        if group:
+            provider_kwargs["group"] = group
+        else:
+            provider_kwargs["group"] = qiskit_config.group if qiskit_config else None
+        if project:
+            provider_kwargs["project"] = project
+        else:
+            provider_kwargs["project"] = (
+                qiskit_config.project if qiskit_config else None
+            )
         try:
             if any(x is not None for x in provider_kwargs.values()):
                 provider = IBMQ.get_provider(**provider_kwargs)
@@ -340,6 +324,57 @@ class IBMQBackend(Backend):
     def backend_info(self) -> BackendInfo:
         return self._backend_info
 
+    @classmethod
+    def _get_backend_info(cls, backend: "_QiskIBMQBackend") -> BackendInfo:
+        config = backend.configuration()
+        characterisation = process_characterisation(backend)
+        averaged_errors = get_avg_characterisation(characterisation)
+        characterisation_keys = [
+            "t1times",
+            "t2times",
+            "Frequencies",
+            "GateTimes",
+        ]
+        arch = characterisation["Architecture"]
+        # filter entries to keep
+        filtered_characterisation = {
+            k: v for k, v in characterisation.items() if k in characterisation_keys
+        }
+        supports_mid_measure = config.simulator or config.multi_meas_enabled
+        supports_fast_feedforward = supports_mid_measure
+        # simulator i.e. "ibmq_qasm_simulator" does not have `supported_instructions`
+        # attribute
+        gate_set = _tk_gate_set(backend)
+        backend_info = BackendInfo(
+            cls.__name__,
+            backend.name(),
+            __extension_version__,
+            arch,
+            gate_set,
+            supports_midcircuit_measurement=supports_mid_measure,
+            supports_fast_feedforward=supports_fast_feedforward,
+            all_node_gate_errors=characterisation["NodeErrors"],
+            all_edge_gate_errors=characterisation["EdgeErrors"],
+            all_readout_errors=characterisation["ReadoutErrors"],
+            averaged_node_gate_errors=averaged_errors["node_errors"],
+            averaged_edge_gate_errors=averaged_errors["edge_errors"],
+            averaged_readout_errors=averaged_errors["readout_errors"],
+            misc={"characterisation": filtered_characterisation},
+        )
+        return backend_info
+
+    @classmethod
+    def available_devices(cls, **kwargs: Any) -> List[BackendInfo]:
+        provider: Optional["AccountProvider"] = kwargs.get("account_provider")
+        if provider is None:
+            provider = cls._get_provider(
+                kwargs.get("hub"), kwargs.get("group"), kwargs.get("project"), None
+            )
+        backend_info_list = [
+            cls._get_backend_info(backend) for backend in provider.backends()
+        ]
+        return backend_info_list
+
     @property
     def required_predicates(self) -> List[Predicate]:
         predicates = [
